package Net::NicoVideo::Content::TagRSS;

use strict;
use warnings;
use utf8;
use vars qw($VERSION);
$VERSION = '0.01_20';

use base qw/Net::NicoVideo::Decorator/;

sub members {
    ();
}

1;
__END__
